@@ -1,5 +1,57 @@
 #if 0
 
+N_("Rice Maize Apple Cake")
+N_("Simple wheat-free yeast dough. You can use rice and maize flour from your local Asian food store.")
+N_("Peel and wedge apples.")
+N_("Mix dry ingredients for the dough.")
+N_("Add rice drink to dough.")
+N_("Knead dough with a dough mixer with dough hook until no small clumps remain.")
+N_("[timer:00:20:00]Let the dough rest.")
+N_("Place parchment paper on a baking tray.")
+N_("Spread the dough onto the parchment paper.")
+N_("Push the apple wedges into the dough.")
+N_("Put cinnamon sugar on top.")
+N_("[timer:00:45:00][temperature:180C]Bake in the oven.")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Dough")
+N_("Apples")
+N_("Apples")
+N_("Tzatziki sauce")
+N_("   ")
+N_("To prepare this traditional Greek tzatziki sauce recipe, remove the skin and the seeds of the cucumber and grate it into a large bowl. Season with salt and pepper and leave aside for 10 minutes.")
+N_("    Wrap the grated cucumber in a towel and squeeze, in order to get rid of the excess water.")
+N_("    Assemble the tzatziki sauce. In a bowl, add the cucumber, the minced garlic and olive oil, the yogurt, 1-2 tbsps of red wine vinegar, a pinch of salt and blend, until the ingredients are combined. Store the tzatziki sauce in the fridge and always serve cold. (Alternatively, if you have a blender, pour in the olive oil and garlic and blend until combined. Then mix with the rest of the ingredients using a spoon. This will help the garlic to mix better with the rest of the ingredients).")
+N_("    Prepare this traditional tzatziki sauce for your friends and family and serve as a delicious dip with some warm pita breads aside, or as a sauce for Greek-style souvlaki. Enjoy!")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Soy Chicken (See Yao Gai)")
+N_("This recipe must be followed to the TEE. If you do not add the soy sauce it then becomes Bok Yao Gai (White Boiled Chicken). Never the less a very easy way of making a Chinese boiled chicken. (My recipe tested over 20 years)")
+N_("Take your chicken out of the refrigerator an hour before you plan to cook. You'll want it at room temperature when it hits the pot. Remove the giblets, and thoroughly rinse the chicken inside and out.")
+N_("Add all ingredients into the pot.")
+N_("Add enough water to cover the chicken. (eye ball it)")
+N_("Bring water to rolling boil and slowly insert the chicken into the pot. Now make sure the water covers the chicken completely.Add more water at this point to cover the chicken completely.")
+N_("Bring the water back up to a boil cover and cook for about two minutes. (yes I said for only two minutes)")
+N_("Shut the stove off, do not lift the lid to peek. (yes you lift the lid don't complain it did not work)")
+N_("Come back about  5 hours later, lift the chicken out drain make sure all the water has left the chicken. Discard the rest of the ingredients in the pot it is no longer needed.")
+N_("Put the chicken in the frig for about 3 hours to completely cool.")
+N_("Now you can chop it into what ever pierces you wish.")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
+N_("Ingredients")
 N_("Struwen")
 N_("Struven are yeast pancakes which are traditionally eaten on good Friday in Germany, predominantly in Münsterland, but also in lower Rhine region.")
 N_("https://de.wikipedia.org/wiki/Struwen")
