@@ -27,7 +27,8 @@ typedef enum { /*< flags >*/
         GR_DIET_NUT_FREE      =  2,
         GR_DIET_VEGAN         =  4,
         GR_DIET_VEGETARIAN    =  8,
-        GR_DIET_MILK_FREE     = 16
+        GR_DIET_MILK_FREE     = 16,
+        GR_DIET_HALAL         = 32
 } GrDiets;
 
 
