@@ -32,8 +32,8 @@
 
 typedef struct
 {
-        GrNumber amount;
-        gchar *unit;
+        double amount;
+        GrUnit unit;
         gchar *name;
         gchar *segment;
 } Ingredient;
@@ -42,7 +42,6 @@ static void
 ingredient_free (Ingredient *ing)
 {
         g_free (ing->name);
-        g_free (ing->unit);
         g_free (ing->segment);
         g_free (ing);
 }
@@ -73,7 +72,7 @@ gr_ingredients_list_populate (GrIngredientsList  *ingredients,
                 char *unit;
                 char *ingredient;
                 char *segment;
-                const char *u;
+                GrUnit u;
                 const char *s;
                 Ingredient *ing;
                 g_autoptr(GError) local_error = NULL;
@@ -93,7 +92,7 @@ gr_ingredients_list_populate (GrIngredientsList  *ingredients,
                 segment = fields[3];
 
                 ing = g_new0 (Ingredient, 1);
-                gr_number_set_fraction (&ing->amount, 0, 0);
+                ing->amount = 1.0;
                 if (amount[0] != '\0' &&
                     !gr_number_parse (&ing->amount, &amount, &local_error)) {
                         g_message ("failed to parse amount '%s': %s", amount, local_error->message);
@@ -101,14 +100,13 @@ gr_ingredients_list_populate (GrIngredientsList  *ingredients,
                         continue;
                 }
 
-                u = "";
+                u = GR_UNIT_UNKNOWN;
                 if (unit[0] != '\0' &&
-                    ((u = gr_unit_parse (&unit, &local_error)) == NULL)) {
+                    ((u = gr_unit_parse (&unit, &local_error)) == GR_UNIT_UNKNOWN)) {
                         g_message ("%s; using %s as-is", local_error->message, unit);
-                        u = unit;
                 }
 
-                ing->unit = g_strdup (u);
+                ing->unit = u;
                 ing->segment = g_strdup (segment);
 
                 s = gr_ingredient_find (ingredient);
@@ -172,27 +170,23 @@ gr_ingredients_list_validate (const char  *text,
 }
 
 static void
-ingredient_scale_unit (Ingredient *ing, int num, int denom, GString *s)
+ingredient_scale_unit (Ingredient *ing, double scale, GString *s)
 {
         g_autofree char *scaled = NULL;
-        GrNumber *snum;
 
-        snum = gr_number_new_fraction (num, denom);
-        gr_number_multiply (&ing->amount, snum, snum);
-        scaled = gr_number_format (snum);
-        g_free (snum);
+        scaled = gr_number_format (scale * ing->amount);
 
         g_string_append (s, scaled);
         if (ing->unit) {
                 g_string_append (s, " ");
-                g_string_append (s, ing->unit);
+                g_string_append (s, gr_unit_get_abbreviation (ing->unit));
         }
 }
 
 static void
 ingredient_scale (Ingredient *ing, int num, int denom, GString *s)
 {
-        ingredient_scale_unit (ing, num, denom, s);
+        ingredient_scale_unit (ing, (double)num / (double)denom, s);
         g_string_append (s, " ");
         g_string_append (s, ing->name);
         g_string_append (s, "\n");
@@ -245,8 +239,7 @@ char *
 gr_ingredients_list_scale_unit (GrIngredientsList *ingredients,
                                 const char        *segment,
                                 const char        *name,
-                                int                num,
-                                int                denom)
+                                double             scale)
 {
         GList *l;
 
@@ -258,7 +251,7 @@ gr_ingredients_list_scale_unit (GrIngredientsList *ingredients,
                         GString *s;
 
                         s = g_string_new ("");
-                        ingredient_scale_unit (ing, num, denom, s);
+                        ingredient_scale_unit (ing, scale, s);
 
                         return g_string_free (s, FALSE);
                 }
@@ -267,7 +260,7 @@ gr_ingredients_list_scale_unit (GrIngredientsList *ingredients,
         return NULL;
 }
 
-const char *
+GrUnit
 gr_ingredients_list_get_unit (GrIngredientsList *ingredients,
                               const char        *segment,
                               const char        *name)
@@ -283,10 +276,10 @@ gr_ingredients_list_get_unit (GrIngredientsList *ingredients,
                 }
         }
 
-        return NULL;
+        return GR_UNIT_UNKNOWN;
 }
 
-GrNumber *
+double
 gr_ingredients_list_get_amount (GrIngredientsList *ingredients,
                                 const char        *segment,
                                 const char        *name)
@@ -298,11 +291,11 @@ gr_ingredients_list_get_amount (GrIngredientsList *ingredients,
 
                 if (g_strcmp0 (segment, ing->segment) == 0 &&
                     g_strcmp0 (name, ing->name) == 0) {
-                        return &ing->amount;
+                        return ing->amount;
                 }
         }
 
-        return NULL;
+        return 0.0;
 }
 
 
