@@ -36,6 +36,7 @@
 #include "gr-utils.h"
 #include "gr-recipe-tile.h"
 #include "gr-chef-tile.h"
+#include "gr-gourmet-format.h"
 
 
 struct _GrRecipeImporter
@@ -82,7 +83,8 @@ struct _GrRecipeImporter
         char *recipe_instructions;
         char *recipe_notes;
         char **recipe_paths;
-        int recipe_serves;
+        double recipe_yield;
+        char *recipe_yield_unit;
         int recipe_spiciness;
         int recipe_default_image;
         GrDiets recipe_diets;
@@ -324,7 +326,8 @@ import_recipe (GrRecipeImporter *importer)
                       "ingredients", importer->recipe_ingredients,
                       "instructions", importer->recipe_instructions,
                       "notes", importer->recipe_notes,
-                      "serves", importer->recipe_serves,
+                      "yield", importer->recipe_yield,
+                      "yield-unit", importer->recipe_yield_unit,
                       "spiciness", importer->recipe_spiciness,
                       "default-image", importer->recipe_default_image,
                       "diets", importer->recipe_diets,
@@ -411,6 +414,32 @@ show_recipe_conflict_dialog (GrRecipeImporter *importer)
         gtk_widget_show (dialog);
 }
 
+static gboolean
+parse_yield (const char  *text,
+             double      *amount,
+             char       **unit)
+{
+        char *tmp;
+        const char *str;
+        g_autofree char *num = NULL;
+
+        g_clear_pointer (unit, g_free);
+
+        tmp = (char *)text;
+        skip_whitespace (&tmp);
+        str = tmp;
+        if (!gr_number_parse (amount, &tmp, NULL)) {
+                *unit = g_strdup (str);
+                return FALSE;
+        }
+
+        skip_whitespace (&tmp);
+        if (tmp)
+                *unit = g_strdup (tmp);
+
+        return TRUE;
+}
+
 #define handle_or_clear_error(error) \
         if (error) { \
                 if (!g_error_matches (error, G_KEY_FILE_ERROR, G_KEY_FILE_ERROR_KEY_NOT_FOUND)) { \
@@ -435,6 +464,7 @@ import_next_recipe (GrRecipeImporter *importer)
         gsize length2;
         g_autoptr(GError) error = NULL;
         const char *id;
+        g_autofree char *yield_str = NULL;
 
         store = gr_recipe_store_get ();
 
@@ -465,8 +495,14 @@ next:
         importer->recipe_ingredients = key_file_get_string (importer->recipes_keyfile, id, "Ingredients");
         importer->recipe_instructions = key_file_get_string (importer->recipes_keyfile, id, "Instructions");
         importer->recipe_notes = key_file_get_string (importer->recipes_keyfile, id, "Notes");
-        importer->recipe_serves = g_key_file_get_integer (importer->recipes_keyfile, id, "Serves", &error);
+
+        yield_str = key_file_get_string (importer->recipes_keyfile, id, "Yield");
         handle_or_clear_error (error);
+        if (!yield_str || !parse_yield (yield_str, &importer->recipe_yield, &importer->recipe_yield_unit)) {
+
+                importer->recipe_yield = (double)g_key_file_get_integer (importer->recipes_keyfile, id, "Serves", &error);
+                importer->recipe_yield_unit = g_strdup (_("servings"));
+        }
         importer->recipe_spiciness = g_key_file_get_integer (importer->recipes_keyfile, id, "Spiciness", &error);
         handle_or_clear_error (error);
         importer->recipe_default_image = g_key_file_get_integer (importer->recipes_keyfile, id, "DefaultImage", &error);
@@ -803,6 +839,22 @@ gr_recipe_importer_import_from (GrRecipeImporter *importer,
                      _("This build does not support importing"));
         error_cb (NULL, error, importer);
 #else
+        g_autofree char *basename = NULL;
+
+        basename = g_file_get_basename (file);
+        if (g_str_has_suffix (basename, ".xml")) {
+                g_autoptr(GError) error = NULL;
+                GList *recipes;
+
+                if (!(recipes = gr_gourmet_format_import (file, &error)))
+                        error_cb (NULL, error, importer);
+
+                g_signal_emit (importer, done_signal, 0, recipes);
+                g_list_free (recipes);
+
+                return;
+        }
+
         importer->dir = g_mkdtemp (g_build_filename (g_get_tmp_dir (), "recipeXXXXXX", NULL));
         importer->output = g_file_new_for_path (importer->dir);
 
