@@ -32,8 +32,12 @@ G_DECLARE_FINAL_TYPE (GrShoppingPage, gr_shopping_page, GR, SHOPPING_PAGE, GtkBo
 
 GtkWidget      *gr_shopping_page_new      (void);
 
+GList * get_ingredients (GrShoppingPage *page);
+
 void            gr_shopping_page_populate (GrShoppingPage *self);
 
-GList          *gr_shopping_page_get_recipes (GrShoppingPage *self);
+gboolean		gr_send_mail_finish (GAsyncResult *result, GError **error);
+
+void			item_free (gpointer data);
 
 G_END_DECLS
