@@ -76,6 +76,7 @@ void            gr_window_show_my_chef_information   (GrWindow   *window);
 void            gr_window_show_about_dialog          (GrWindow   *window);
 void            gr_window_show_report_issue          (GrWindow   *window);
 void            gr_window_show_news                  (GrWindow   *window);
+void            gr_window_show_surprise              (GrWindow   *window);
 
 void            gr_window_load_recipe                (GrWindow   *window,
                                                       GFile      *file);
@@ -83,5 +84,6 @@ void            gr_window_save_all                   (GrWindow   *window);
 void            gr_window_timer_expired              (GrWindow   *window,
                                                       GrRecipe   *recipe,
                                                       int         step);
+void            gr_window_confirm_shopping_exported  (GrWindow *window);
 
 G_END_DECLS
