@@ -107,15 +107,6 @@ gd_main_box_item_activated_cb (GdMainBox *self, GdMainBoxChild *child)
     gd_main_box_activate_item_for_child (self, child);
 }
 
-static void
-gd_main_box_model_items_changed_cb (GdMainBox *self, guint position, guint removed, guint added)
-{
-  if (removed == 0)
-    return;
-
-  g_signal_emit (self, signals[SELECTION_CHANGED], 0);
-}
-
 static void
 gd_main_box_selection_changed_cb (GdMainBox *self)
 {
@@ -269,7 +260,6 @@ static void
 gd_main_box_class_init (GdMainBoxClass *klass)
 {
   GObjectClass *oclass = G_OBJECT_CLASS (klass);
-  GtkWidgetClass *wclass = GTK_WIDGET_CLASS (klass);
 
   oclass->get_property = gd_main_box_get_property;
   oclass->set_property = gd_main_box_set_property;
@@ -486,24 +476,9 @@ gd_main_box_set_model (GdMainBox *self, GListModel *model)
 
   priv = gd_main_box_get_instance_private (self);
 
-  if (model == priv->model)
+  if (!g_set_object (&priv->model, model))
     return;
 
-  if (priv->model)
-    g_signal_handlers_disconnect_by_func (priv->model, gd_main_box_model_items_changed_cb, self);
-
-  g_clear_object (&priv->model);
-
-  if (model != NULL)
-    {
-      priv->model = g_object_ref (model);
-      g_signal_connect_object (priv->model,
-                               "items-changed",
-                               G_CALLBACK (gd_main_box_model_items_changed_cb),
-                               self,
-                               G_CONNECT_SWAPPED);
-    }
-
   gd_main_box_generic_set_model (GD_MAIN_BOX_GENERIC (priv->current_box), priv->model);
   g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_MODEL]);
 }
